@@ -100,20 +100,12 @@ urlpatterns = [
         name="parsednotification",
     ),
     # Notification Source
-    path("settings/", views.NotificationSourceListView.as_view(), name="notificationsource_list"),
-    path("settings/add/", views.NotificationSourceEditView.as_view(), name="notificationsource_add"),
-    path("settings/<uuid:pk>/edit/", views.NotificationSourceEditView.as_view(), name="notificationsource_edit"),
-    path("settings/<uuid:pk>/delete/", views.NotificationSourceDeleteView.as_view(), name="notificationsource_delete"),
+    path("source/", views.NotificationSourceListView.as_view(), name="notificationsource_list"),
+    path("source/<slug:slug>/edit/", views.NotificationSourceEditView.as_view(), name="notificationsource_edit"),
+    path("source/<slug:slug>/", views.NotificationSourceView.as_view(), name="notificationsource"),
+    path("source/edit/", views.NotificationSourceBulkEditView.as_view(), name="notificationsource_bulk_edit"),
     path(
-        "settings/delete/",
-        views.NotificationSourceBulkDeleteView.as_view(),
-        name="notificationsource_bulk_delete",
-    ),
-    path("settings/<uuid:pk>/", views.NotificationSourceView.as_view(), name="notificationsource"),
-    path("settings/edit/", views.NotificationSourceBulkEditView.as_view(), name="notificationsource_bulk_edit"),
-    path("settings/import/", views.NotificationSourceBulkImportView.as_view(), name="notificationsource_import"),
-    path(
-        "settings/<uuid:pk>/changelog/",
+        "source/<slug:slug>/changelog/",
         ObjectChangeLogView.as_view(),
         name="notificationsource_changelog",
         kwargs={"model": NotificationSource},
